@@ -25,12 +25,18 @@
  *
  */
 
+#include "os.h"
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <stdio.h>
 #include <fcntl.h>
+
+#if !defined(COMP_MSC)
 #include <unistd.h>
 #include <inttypes.h>
+#endif
+
 #include <limits.h>
 #include <stdlib.h>
 #include <string.h>
@@ -73,46 +79,46 @@ typedef struct
 
 
 typedef struct _avisuperindex_entry {
-    unsigned long long qwOffset;           // absolute file offset
-    unsigned long dwSize;                  // size of index chunk at this offset
-    unsigned long dwDuration;              // time span in stream ticks
+    uint64_t qwOffset;           // absolute file offset
+    uint32_t dwSize;                  // size of index chunk at this offset
+    uint32_t dwDuration;              // time span in stream ticks
 } avisuperindex_entry;
 
 typedef struct _avistdindex_entry {
-    unsigned long dwOffset;                // qwBaseOffset + this is absolute file offset
-    unsigned long dwSize;                  // bit 31 is set if this is NOT a keyframe
+    uint32_t dwOffset;                // qwBaseOffset + this is absolute file offset
+    uint32_t dwSize;                  // bit 31 is set if this is NOT a keyframe
 } avistdindex_entry;
 
-
-// Base Index Form 'indx'
-typedef struct _avisuperindex_chunk {
-    char           fcc[4];
-    unsigned long  dwSize;                 // size of this chunk
-    unsigned short wLongsPerEntry;         // size of each entry in aIndex array (must be 8 for us)
-    unsigned char  bIndexSubType;          // future use. must be 0
-    unsigned char  bIndexType;             // one of AVI_INDEX_* codes
-    unsigned long  nEntriesInUse;          // index of first unused member in aIndex array
-    char           dwChunkId[4];           // fcc of what is indexed
-    unsigned long  dwReserved[3];          // meaning differs for each index type/subtype.
-                                           // 0 if unused
-    avisuperindex_entry *aIndex;
-} avisuperindex_chunk;
-    
 // Standard index 
 typedef struct _avistdindex_chunk {
     char           fcc[4];                 // ix##
-    unsigned long  dwSize;                 // size of this chunk
-    unsigned short wLongsPerEntry;         // must be sizeof(aIndex[0])/sizeof(DWORD)
-    unsigned char  bIndexSubType;          // must be 0
-    unsigned char  bIndexType;             // must be AVI_INDEX_OF_CHUNKS
-    unsigned long  nEntriesInUse;          //
+    uint32_t  dwSize;                 // size of this chunk
+    uint16_t wLongsPerEntry;         // must be sizeof(aIndex[0])/sizeof(DWORD)
+    uint8_t  bIndexSubType;          // must be 0
+    uint8_t  bIndexType;             // must be AVI_INDEX_OF_CHUNKS
+    uint32_t  nEntriesInUse;          //
     char           dwChunkId[4];           // '##dc' or '##db' or '##wb' etc..
-    unsigned long long qwBaseOffset;       // all dwOffsets in aIndex array are relative to this
-    unsigned long  dwReserved3;            // must be 0
+    uint64_t qwBaseOffset;       // all dwOffsets in aIndex array are relative to this
+    uint32_t  dwReserved3;            // must be 0
     avistdindex_entry *aIndex;
 } avistdindex_chunk;
     
 
+// Base Index Form 'indx'
+typedef struct _avisuperindex_chunk {
+    char           fcc[4];
+    uint32_t  dwSize;                 // size of this chunk
+    uint16_t wLongsPerEntry;         // size of each entry in aIndex array (must be 8 for us)
+    uint8_t  bIndexSubType;          // future use. must be 0
+    uint8_t  bIndexType;             // one of AVI_INDEX_* codes
+    uint32_t  nEntriesInUse;          // index of first unused member in aIndex array
+    char           dwChunkId[4];           // fcc of what is indexed
+    uint32_t  dwReserved[3];          // meaning differs for each index type/subtype.
+                                           // 0 if unused
+    avisuperindex_entry *aIndex;           // where are the ix## chunks
+    avistdindex_chunk **stdindex;          // the ix## chunks itself (array)
+} avisuperindex_chunk;
+    
 
 
 typedef struct track_s
@@ -142,6 +148,57 @@ typedef struct track_s
 
 } track_t;
 
+typedef struct
+{
+  uint32_t  bi_size;
+  uint32_t  bi_width;
+  uint32_t  bi_height;
+  uint16_t  bi_planes;
+  uint16_t  bi_bit_count;
+  uint32_t  bi_compression;
+  uint32_t  bi_size_image;
+  uint32_t  bi_x_pels_per_meter;
+  uint32_t  bi_y_pels_per_meter;
+  uint32_t  bi_clr_used;
+  uint32_t  bi_clr_important;
+} alBITMAPINFOHEADER;
+
+typedef struct __attribute__((__packed__))
+{
+  uint16_t  w_format_tag;
+  uint16_t  n_channels;
+  uint32_t  n_samples_per_sec;
+  uint32_t  n_avg_bytes_per_sec;
+  uint16_t  n_block_align;
+  uint16_t  w_bits_per_sample;
+  uint16_t  cb_size;
+} alWAVEFORMATEX;
+
+typedef struct __attribute__((__packed__))
+{
+  uint32_t fcc_type; 
+  uint32_t fcc_handler; 
+  uint32_t dw_flags; 
+  uint32_t dw_caps; 
+  uint16_t w_priority;
+  uint16_t w_language;
+  uint32_t dw_scale;
+  uint32_t dw_rate;
+  uint32_t dw_start;
+  uint32_t dw_length;
+  uint32_t dw_initial_frames;
+  uint32_t dw_suggested_buffer_size;
+  uint32_t dw_quality;
+  uint32_t dw_sample_size;
+  uint32_t dw_left;
+  uint32_t dw_top;
+  uint32_t dw_right;
+  uint32_t dw_bottom;
+  uint32_t dw_edit_count;
+  uint32_t dw_format_change_count;
+  char     sz_name[64];
+} alAVISTREAMINFO;
+
 typedef struct
 {
   
@@ -159,7 +216,7 @@ typedef struct
   long   video_pos;         /* Number of next frame to be read
 			       (if index present) */
   
-  unsigned long max_len;    /* maximum video chunk present */
+  uint32_t max_len;    /* maximum video chunk present */
   
   track_t track[AVI_MAX_TRACKS];  // up to AVI_MAX_TRACKS audio tracks supported
   
@@ -170,22 +227,25 @@ typedef struct
   off_t  v_codech_off;      /* absolut offset of video codec (strh) info */ 
   off_t  v_codecf_off;      /* absolut offset of video codec (strf) info */ 
   
-  unsigned char (*idx)[16]; /* index entries (AVI idx1 tag) */
+  uint8_t (*idx)[16]; /* index entries (AVI idx1 tag) */
 
   video_index_entry *video_index;
   avisuperindex_chunk *video_superindex;  /* index of indices */
   int is_opendml;           /* set to 1 if this is an odml file with multiple index chunks */
   
   off_t  last_pos;          /* Position of last frame written */
-  unsigned long last_len;          /* Length of last frame written */
-  int must_use_index;              /* Flag if frames are duplicated */
+  uint32_t last_len;   /* Length of last frame written */
+  int must_use_index;       /* Flag if frames are duplicated */
   off_t  movi_start;
+  int total_frames;         /* total number of frames if dmlh is present */
   
   int anum;            // total number of audio tracks 
   int aptr;            // current audio working track 
   int comment_fd;      // Read avi header comments from this fd
   char *index_file;    // read the avi index from this file
   
+  alBITMAPINFOHEADER *bitmap_info_header;
+  alWAVEFORMATEX *wave_format_ex[AVI_MAX_TRACKS];
 } avi_t;
 
 #define AVI_MODE_WRITE  0
@@ -316,8 +376,8 @@ int  AVI_read_data(avi_t *AVI, char *vidbuf, long max_vidbuf,
                                long *len);
 
 void AVI_print_error(char *str);
-char *AVI_strerror();
-char *AVI_syserror();
+char *AVI_strerror(void);
+char *AVI_syserror(void);
 
 int AVI_scan(char *name);
 int AVI_dump(char *name, int mode);
@@ -326,7 +386,7 @@ char *AVI_codec2str(short cc);
 int AVI_file_check(char *import_file);
 
 void AVI_info(avi_t *avifile);
-uint64_t AVI_max_size();
+uint64_t AVI_max_size(void);
 int avi_update_header(avi_t *AVI);
 
 int AVI_set_audio_track(avi_t *AVI, int track);
@@ -341,26 +401,26 @@ int  AVI_get_comment_fd(avi_t *AVI);
 
 struct riff_struct 
 {
-  unsigned char id[4];   /* RIFF */
-  unsigned long len;
-  unsigned char wave_id[4]; /* WAVE */
+  uint8_t id[4];   /* RIFF */
+  uint32_t len;
+  uint8_t wave_id[4]; /* WAVE */
 };
 
 
 struct chunk_struct 
 {
-	unsigned char id[4];
-	unsigned long len;
+	uint8_t id[4];
+	uint32_t len;
 };
 
 struct common_struct 
 {
-	unsigned short wFormatTag;
-	unsigned short wChannels;
-	unsigned long dwSamplesPerSec;
-	unsigned long dwAvgBytesPerSec;
-	unsigned short wBlockAlign;
-	unsigned short wBitsPerSample;  /* Only for PCM */
+	uint16_t wFormatTag;
+	uint16_t wChannels;
+	uint32_t dwSamplesPerSec;
+	uint32_t dwAvgBytesPerSec;
+	uint16_t wBlockAlign;
+	uint16_t wBitsPerSample;  /* Only for PCM */
 };
 
 struct wave_header 
