@@ -25,10 +25,12 @@ filter_32drop.so
 filter_aclip.so
 filter_astat.so
 filter_compare.so
+filter_control.so
 filter_cpaudio.so
 filter_cshift.so
 filter_cut.so
 filter_decimate.so
+filter_denoise3d.so
 filter_detectsilence.so
 filter_detectclipping.so
 filter_dilyuvmmx.so
@@ -125,6 +127,8 @@ beer
   s/R.*Y.*4/It can handle rgb,yuv and yuv422 mode. /
   s/R.*Y/It can handle rgb and yuv mode. /
   s/Y.*R/It can handle rgb and yuv mode. /
+  s/Y.*4/It can handle yuv and yuv422 mode. /
+  s/4.*Y/It can handle yuv and yuv422 mode. /
   s/R/It can handle rgb mode only. /
   s/Y/It can handle yuv mode only. /
   s/M.*E.*O/It supports multiple instances and can run as a pre and\/or as a post filter. /
