@@ -39,7 +39,7 @@
 #endif
 
 #define MOD_NAME    "export_mpeg2enc.so"
-#define MOD_VERSION "v1.1.9 (2003-08-23)"
+#define MOD_VERSION "v1.1.10 (2003-10-30)"
 #define MOD_CODEC   "(video) MPEG 1/2"
 
 #define MOD_PRE mpeg2enc
@@ -60,6 +60,12 @@ static int capability_flag=TC_CAP_YUV|TC_CAP_RGB;
 #define Y4M_MAGIC "YUV4MPEG2"
 #define Y4M_FRAME_MAGIC "FRAME"
 
+#include "probe_export.h"
+
+static char *m1v=".m1v";
+static char *m2v=".m2v";
+
+
 static int y4m_snprint_xtags(char *s, int maxn, y4m_xtag_list_t *xtags)
 {
   int i, room;
@@ -135,8 +141,6 @@ MOD_open
   int frc=0, asr=0;
   char *tv_type="-n p";
   char *pulldown="";
-  char *m1v=".m1v";
-  char *m2v=".m2v";
   int fields = !!vob->encode_fields;
 
   if(param->flag == TC_VIDEO) 
@@ -214,7 +218,10 @@ MOD_open
       sprintf(buf2, "%s %s", tv_type, pulldown); 
     
     //tibit: do not write to /dev/null.m1v
-    if (!strncmp(vob->video_out_file, "/dev/null", 9)) {
+    m1v = video_ext;
+    m2v = video_ext;
+
+    if (strlen(vob->video_out_file)>=9 && !strncmp(vob->video_out_file, "/dev/null", 9)) {
 	m1v="";
 	m2v="";
     }
@@ -227,9 +234,9 @@ MOD_open
       //exactly to the VCD2.0 specification.
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 1 -F %d %s %s -o \"%s\"%s", verb, fields, frc, buf2, (vob->ex_v_string?vob->ex_v_string:""),vob->video_out_file, m1v);
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 1 -F %d %s %s -o \"%s%s\"", verb, fields, frc, buf2, (vob->ex_v_string?vob->ex_v_string:""),vob->video_out_file, m1v);
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 1 -F %d %s %s -o \"%s\"%s %s", verb, fields, frc, buf2, (vob->ex_v_string?vob->ex_v_string:""), vob->video_out_file, m1v, p2);
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 1 -F %d %s %s -o \"%s%s\" %s", verb, fields, frc, buf2, (vob->ex_v_string?vob->ex_v_string:""), vob->video_out_file, m1v, p2);
       break;
       
     case 2:
@@ -237,9 +244,9 @@ MOD_open
       //User VCD 
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 2 -4 2 -2 3 -b %d -F %d %s -o \"%s\"%s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 2 -4 2 -2 3 -b %d -F %d %s -o \"%s%s\" %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 2 -4 2 -2 3 -b %d -F %d %s -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 2 -4 2 -2 3 -b %d -F %d %s -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       break;
       
     case 3:
@@ -247,9 +254,9 @@ MOD_open
       //Generic MPEG2
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 3 -4 2 -2 3 -b %d -s -F %d %s -o \"%s\"%s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 3 -4 2 -2 3 -b %d -s -F %d %s -o \"%s%s\" %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 3 -4 2 -2 3 -b %d -s -F %d %s -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 3 -4 2 -2 3 -b %d -s -F %d %s -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       break;
       
     case 4:
@@ -258,9 +265,9 @@ MOD_open
       //exactly  to  the  SVCD2.0 specification
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 4 -F %d %s -o \"%s\"%s %s", verb, fields, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 4 -F %d %s -o \"%s%s\" %s", verb, fields, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 4 -F %d %s -o \"%s\"%s %s %s", verb, fields, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 4 -F %d %s -o \"%s%s\" %s %s", verb, fields, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       break;
 
     case 5:
@@ -268,16 +275,16 @@ MOD_open
       //User SVCD
 
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 5 -4 2 -2 3 -b %d -F %d %s -V 230 -o \"%s\"%s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 5 -4 2 -2 3 -b %d -F %d %s -V 230 -o \"%s%s\" %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 5 -4 2 -2 3 -b %d -F %d %s -V 230 -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 5 -4 2 -2 3 -b %d -F %d %s -V 230 -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       break;
       
     case 6:
       
       // Manual parameter mode.
       
-      sprintf(buf, "mpeg2enc -v %d -I %d -b %d -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+      sprintf(buf, "mpeg2enc -v %d -I %d -b %d -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, vob->video_out_file, m2v, p2?p2:"", (vob->ex_v_string?vob->ex_v_string:""));
       break;
       
     case 8:
@@ -285,9 +292,9 @@ MOD_open
       //DVD
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 8 -b %d -F %d %s -o \"%s\"%s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 8 -b %d -F %d %s -o \"%s%s\" %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -f 8 -b %d -F %d %s -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -f 8 -b %d -F %d %s -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m2v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       
       break;
 
@@ -298,14 +305,14 @@ MOD_open
       //Generic MPEG1
       
       if(p2==NULL) 
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 0 -4 2 -2 3 -b %d -F %d %s -o \"%s\"%s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 0 -4 2 -2 3 -b %d -F %d %s -o \"%s%s\" %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, (vob->ex_v_string?vob->ex_v_string:""));
       else
-	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 0 -4 2 -2 3 -b %d -F %d %s -o \"%s\"%s %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, p2, (vob->ex_v_string?vob->ex_v_string:""));
+	sprintf(buf, "mpeg2enc -v %d -I %d -q 3 -f 0 -4 2 -2 3 -b %d -F %d %s -o \"%s%s\" %s %s", verb, fields, vob->divxbitrate, frc, buf2, vob->video_out_file, m1v, p2, (vob->ex_v_string?vob->ex_v_string:""));
       break;
     }
     
     fprintf(stderr,"[%s] cmd=%s\n", MOD_NAME, buf);
-    
+
     sa_ip = popen(buf, "w");
     if (!sa_ip) return(TC_EXPORT_ERROR);
     
@@ -335,8 +342,10 @@ MOD_open
 
 MOD_init
 {
+
   if(param->flag == TC_VIDEO) 
   {
+    int prof = 0;
     fprintf(stderr, "[%s] *** init-v *** !\n", MOD_NAME); 
 
    //ThOe added RGB2YUV cap
@@ -351,6 +360,12 @@ MOD_init
     sa_height = vob->ex_v_height;
     sa_size_l = sa_width * sa_height;
     sa_size_c = sa_size_l/4;
+
+    if (vob->ex_v_fcc) prof = atoi(vob->ex_v_fcc);
+    if ( !(probe_export_attributes & TC_PROBE_NO_EXPORT_VEXT) ) {
+	if (prof < 3) video_ext = ".m1v";
+	else video_ext = ".m2v";
+    }
     
     return(0);
   }
