@@ -65,7 +65,7 @@
  ****************************************************************************/
 
 #define MOD_NAME    "export_xvid4.so"
-#define MOD_VERSION "v0.0.4 (2003-08-24)"
+#define MOD_VERSION "v0.0.5 (2003-12-05)"
 #define MOD_CODEC  \
 "(video) XviD 1.0.x series (aka API 4.0) | (audio) MPEG/AC3/PCM"
 #define MOD_PRE xvid4_ 
@@ -140,7 +140,6 @@ typedef struct _xvid_transcode_module_t
 	char *cfg_intra_matrix_file;
 	char *cfg_inter_matrix_file;
 	char *cfg_quant_method;
-	char *cfg_payback_method;
 	int cfg_packed;
 	int cfg_closed_gop;
 	int cfg_interlaced;
@@ -154,6 +153,7 @@ typedef struct _xvid_transcode_module_t
 	int cfg_motion;
 	int cfg_stats;
 	int cfg_greyscale;
+	int cfg_turbo;
 
 	/* MPEG4 stream buffer */
 	int   stream_size;
@@ -453,7 +453,7 @@ MOD_close
  ****************************************************************************/
 
 #define SSE2PSNR(sse, width, height) \
-((!(sse)) ? (0.0f) : (48.131f - 10*(float)log10((float)(sse)/((float)((width)*(height))))))
+((!(sse)) ? (99.0f) : (48.131f - 10*(float)log10((float)(sse)/((float)((width)*(height))))))
 
 MOD_stop
 {  
@@ -535,7 +535,7 @@ static void reset_module(xvid_transcode_module_t *mod)
 	mod->rawfd = -1;
 
 	/* Default options */
-	mod->cfg_packed = 0;
+	mod->cfg_packed = 1;
 	mod->cfg_closed_gop = 1;
 	mod->cfg_interlaced = 0;
 	mod->cfg_quarterpel = 0;
@@ -543,15 +543,14 @@ static void reset_module(xvid_transcode_module_t *mod)
 	mod->cfg_trellis = 0;
 	mod->cfg_cartoon = 0;
 	mod->cfg_hqacpred = 1;
-	mod->cfg_chromame = 0;
-	mod->cfg_vhq = 0;
+	mod->cfg_chromame = 1;
+	mod->cfg_vhq = 1;
 	mod->cfg_motion = 6;
+	mod->cfg_turbo = 0;
 	mod->cfg_stats = 0;
+	mod->cfg_greyscale = 0;
 	mod->cfg_quant_method = strdup("h263");
-	mod->cfg_payback_method = strdup("proportional");
-
-	/* No bframes by default but ratio and offset have to be initialized */
-	mod->cfg_create.max_bframes = 0;
+	mod->cfg_create.max_bframes = 2;
 	mod->cfg_create.bquant_ratio = 150;
 	mod->cfg_create.bquant_offset = 100;
 
@@ -644,6 +643,7 @@ static void read_config_file(xvid_transcode_module_t *mod)
 			{"frame_drop_ratio", &create->frame_drop_ratio, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"stats", &mod->cfg_stats, CONF_TYPE_FLAG, 0, 0, 1, NULL},
 			{"greyscale", &mod->cfg_greyscale, CONF_TYPE_FLAG, 0, 0, 1, NULL},
+			{"turbo", &mod->cfg_turbo, CONF_TYPE_FLAG, 0, 0, 1, NULL},
 
 			/* section [quantizer] */
 			{"quantizer", "Quantizer settings", CONF_TYPE_SECTION, 0, 0, 0, NULL},
@@ -665,15 +665,13 @@ static void read_config_file(xvid_transcode_module_t *mod)
 			/* section [cbr] */
 			{"vbr", "VBR settings", CONF_TYPE_SECTION, 0, 0, 0, NULL},
 			{"keyframe_boost", &pass2->keyframe_boost, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
-			{"payback_method", &mod->cfg_payback_method, CONF_TYPE_STRING, 0, 0, 0, NULL},
-			{"bitrate_payback_delay", &pass2->bitrate_payback_delay, CONF_TYPE_INT, CONF_MIN, 0, 0, NULL},
 			{"curve_compression_high", &pass2->curve_compression_high, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"curve_compression_low", &pass2->curve_compression_low, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
+			{"overflow_control_strength", &pass2->overflow_control_strength, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"max_overflow_improvement", &pass2->max_overflow_improvement, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"max_overflow_degradation", &pass2->max_overflow_degradation, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
-			{"kftreshold", &pass2->kftreshold, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
 			{"kfreduction", &pass2->kfreduction, CONF_TYPE_INT, CONF_RANGE, 0, 100, NULL},
-			{"min_key_interval", &pass2->min_key_interval, CONF_TYPE_INT, CONF_MIN, 0, 0, NULL},
+			{"kfthreshold", &pass2->kfthreshold, CONF_TYPE_INT, CONF_MIN, 0, 0, NULL},
 			{"container_frame_overhead", &pass2->container_frame_overhead, CONF_TYPE_INT, CONF_MIN, 0, 0, NULL},
 
 			/* End of the config file */
@@ -724,11 +722,6 @@ static void dispatch_settings(xvid_transcode_module_t *mod)
 	if(mod->cfg_stats)
 		create->global |= XVID_GLOBAL_EXTRASTATS_ENABLE;
 
-	if(!strcasecmp(mod->cfg_payback_method, "bias"))
-		mod->cfg_pass2.payback_method = XVID_PAYBACK_BIAS;
-	else
-		mod->cfg_pass2.payback_method = XVID_PAYBACK_PROP;
-
 	/* Dispatch all settings having an impact on the "frame" structure */
 	frame->vol_flags = 0;
 	frame->vop_flags = 0;
@@ -743,6 +736,11 @@ static void dispatch_settings(xvid_transcode_module_t *mod)
 	if(mod->cfg_greyscale)
 		frame->vop_flags |= XVID_VOP_GREYSCALE;
 
+	if(mod->cfg_cartoon) {
+		frame->vop_flags |= XVID_VOP_CARTOON;
+		frame->motion |= XVID_ME_DETECT_STATIC_MOTION;
+	}
+
 	if(mod->cfg_intra_matrix_file) {
 		frame->quant_intra_matrix = (unsigned char*)read_matrix(mod->cfg_intra_matrix_file);
 		if(frame->quant_intra_matrix != NULL) {
@@ -804,6 +802,13 @@ static void dispatch_settings(xvid_transcode_module_t *mod)
 	if(mod->cfg_vhq >= 4) {
 		frame->motion |= XVID_ME_EXTSEARCH_RD;
 	}
+	if (mod->cfg_turbo) {
+		frame->motion |= XVID_ME_FASTREFINE16;
+		frame->motion |= XVID_ME_FASTREFINE8;
+		frame->motion |= XVID_ME_SKIP_DELTASEARCH;
+		frame->motion |= XVID_ME_FAST_MODEINTERPOLATE;
+		frame->motion |= XVID_ME_BFRAME_EARLYSTOP;
+	}
 
 	/* motion level == 0 means no motion search which is equivalent to
 	 * intra coding only */
@@ -908,15 +913,13 @@ static void set_create_struct(xvid_transcode_module_t *mod, vob_t *vob)
 		/* Apply config file settings if any, or all 0s which lets XviD
 		 * apply its defaults */
 		pass2->keyframe_boost = pass2cfg->keyframe_boost;
-		pass2->payback_method = pass2cfg->payback_method;
-		pass2->bitrate_payback_delay = pass2cfg->bitrate_payback_delay;
 		pass2->curve_compression_high = pass2cfg->curve_compression_high;
 		pass2->curve_compression_low = pass2cfg->curve_compression_low;
+		pass2->overflow_control_strength = pass2cfg->overflow_control_strength;
 		pass2->max_overflow_improvement = pass2cfg->max_overflow_improvement;
 		pass2->max_overflow_degradation = pass2cfg->max_overflow_degradation;
-		pass2->kftreshold = pass2cfg->kftreshold;
 		pass2->kfreduction = pass2cfg->kfreduction;
-		pass2->min_key_interval = pass2cfg->min_key_interval;
+		pass2->kfthreshold = pass2cfg->kfthreshold;
 		pass2->container_frame_overhead = pass2cfg->container_frame_overhead;
 
 		/* Positive bitrate values are bitrates as usual but if the
@@ -1017,6 +1020,12 @@ static void set_frame_struct(xvid_transcode_module_t *mod, vob_t *vob, transfer_
 	x->quant_intra_matrix = xcfg->quant_intra_matrix;
 	x->quant_inter_matrix = xcfg->quant_inter_matrix;
 
+	/* pixel aspect ratio
+	 * transcode.c uses 0 for EXT instead of 15 */
+	x->par = (vob->ex_par==0)? XVID_PAR_EXT: vob->ex_par;
+	x->par_width = vob->ex_par_width;
+	x->par_height = vob->ex_par_height;
+
 	return;
 }
 
