@@ -1,4 +1,12 @@
 /* Map transcode configure defines to libavcodecs */
+#ifndef __AV_CONFIG_H
+#define __AV_CONFIG_H
+
+/* Kludge to see if we had HAVE_MMX defined before we included
+ * config.h - see below ... */
+#ifndef HAVE_MMX
+#define HAD_MMX_FALSE
+#endif
 
 #include "config.h"
 
@@ -15,6 +23,13 @@
 #  define ARCH_POWERPC
 #endif
 
+/* We use HAVE_MMX, but for ffmpeg the Makefile's set it, so
+ * unset it here, else ffmpeg use MMX constructs, even if we
+ * have --disable-mmx */
+#if defined(HAD_MMX_FALSE) && defined(HAVE_MMX)
+#undef HAVE_MMX
+#endif
+
 #ifdef HAVE_DLOPEN
 #  define CONFIG_HAVE_DLOPEN 1
 #endif
@@ -44,3 +59,5 @@
 #define CONFIG_ZLIB 1
 #define SIMPLE_IDCT 1
 #define restrict __restrict__
+
+#endif /* __AV_CONFIG_H */
