@@ -500,7 +500,11 @@ int tc_filter(vframe_list_t *ptr, char *options)
 
     // misc:
 
-    f_time = 1./vob->fps;
+    if (post) {
+	f_time = 1./vob->ex_fps;
+    } else {
+	f_time = 1./vob->fps;
+    }
 
     codec = vob->im_v_codec;
     
@@ -540,7 +544,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
     void * status;
     
     pthread_cancel(thread1);
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
     pthread_cond_signal(&sframe_list_full_cv);
 #endif
     pthread_join(thread1, &status);
