@@ -44,20 +44,20 @@ static unsigned char *bufalloc(int n, size_t size)
 {
 
 #ifdef HAVE_GETPAGESIZE
-   int buffer_align=getpagesize();
+   long buffer_align=getpagesize();
 #else
-   int buffer_align=0;
+   long buffer_align=0;
 #endif
 
    char *buf = malloc(size + buffer_align);
 
-   int adjust;
+   long adjust;
 
    if (buf == NULL) {
        fprintf(stderr, "(%s) out of memory", __FILE__);
    }
    
-   adjust = buffer_align - ((int) buf) % buffer_align;
+   adjust = buffer_align - ((long) buf) % buffer_align;
 
    if (adjust == buffer_align)
       adjust = 0;
@@ -561,7 +561,7 @@ void subtitle_reader()
     
     while(sframe_fill_level(TC_BUFFER_FULL)) {
       pthread_cond_wait(&sframe_list_full_cv, &sframe_list_lock);
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
       pthread_testcancel();
 #endif
     }
