@@ -24,6 +24,18 @@
  */
 
 // ----------------- Changes 
+// 0.9 -> 0.10: marrq
+//		added scene change detection code courtesy of Tilmann Bitterberg
+//		so we won't blend if there's a change of scene (we'll still interpolate)
+//		added clone_phosphor_average
+// 0.8 -> 0.9: marrq
+//		added fancy_clone and associated functions
+// 0.7 -> 0.8: Tilmann Bitterberg
+//		make mode=1 the default
+// 0.6 -> 0.7: marrq
+//		make mode=1 independant of frame numbers, and modified verbose
+//		mode to make a bit more sense given the conditionals
+//		modified "todo" to reflect this
 // 0.5 -> 0.6: Tilmann Bitterberg
 //             Make mode=0 independent of the Frame number transcode
 //             gives us.
@@ -36,24 +48,8 @@
 //             flags.
 //             Fix a bug related to scanrange.
 
-// ----------------- TODO
-//	BUG
-//	make this work with at least -c and hopefully filters cut and skip as well.
-//	Currently, when using -c our counters are at 0, which means if we're
-//	dropping frames, we choose to play catch up instead of dropping
-//	and similar if we clone
-//
-//	feature:
-//	Be able to do something fance when cloning.  I'm thinking of four things,
-// 	1. interpolate field of frame which was cloned with frame that
-//	   follows it.
-//	2. evenly merge/average frames.
-//	3. weighted average, so more intence luminance is stronger seen (think
-//	   of phosphors on a TV
-//	4. temporal weighted average
-
 #define MOD_NAME    "filter_modfps.so"
-#define MOD_VERSION "v0.6 (2003-08-01)"
+#define MOD_VERSION "v0.10 (2003-08-18)"
 #define MOD_CAP     "plugin to modify framerate"
 #define MOD_AUTHOR  "Marrq"
 //#define DEBUG 1
@@ -62,6 +58,7 @@
 #include <stdlib.h>
 #include <sys/stat.h>
 #include <unistd.h>
+#include <inttypes.h>
 
 /* -------------------------------------------------
  *
@@ -88,8 +85,9 @@ static int show_results=0;
  *
  *-------------------------------------------------*/
 
-static int mode=0;
+static int mode=1;
 static double infps  = 29.97;
+static double outfps = 23.976;
 static int infrc  = 0;
 // default settings for NTSC 29.97 -> 23.976
 static int numSample=5;
@@ -101,6 +99,7 @@ static int frbufsize;
 static int frameIn = 0, frameOut = 0;
 static int *framesOK, *framesScore;
 static int scanrange = 0;
+static int clonetype = 0;
 
 static double frc_table[16] = {0,
 			       NTSC_FILM, 24, 25, NTSC_VIDEO, 30, 50, 
@@ -125,9 +124,266 @@ static void help_optstr()
     printf ("\tinfrc : original frc (overwrite infps) [%d]\n",infrc);
     printf ("\tbuffer : number of frames to buffer [%d]\n",numSample);
     printf ("\tsubsample : number of pixels to subsample when examining buffers [%d]\n",offset);
+    printf ("\tclonetype : when cloning and mode=1 do something special [%d]\n",clonetype);
+    printf ("\t\t    0 = none\n");
+    printf ("\t\t    1 = merge fields, cloned frame first(good for interlaced displays)\n");
+    printf ("\t\t    2 = merge fields, cloned frame 2nd (good for interlaced displays)\n");
+    printf ("\t\t    3 = average frames\n");
+    printf ("\t\t    4 = temporally average frame\n");
+    printf ("\t\t    5 = pseudo-phosphor average frames (YUV only) (slow)\n");
     printf ("\tverbose : 0 = not verbose, 1 is verbose [%d]\n",show_results);
 }
 
+#define ABS_u8(a) (((a)^((a)>>7))-((a)>>7))
+
+static int yuv_detect_scenechange(uint8_t *_src, uint8_t *_prev, const int _threshold,
+		const int _scenethreshold, int _width, const int _height, const int srcpitch){
+  uint8_t *src, *src_buf, *srcminus, *prev;
+  const int w=_width;
+  const int h=_height;
+  const int hminus1 = h-1;
+  int x,y,count=0,scenechange=0;
+
+  /* Skip first and last lines, they'll get a free ride. */
+  src_buf = _src;
+  src = src_buf + srcpitch;
+  srcminus = src - srcpitch;
+  prev = _prev + srcpitch;
+
+  for (y = 1; y < hminus1; y++){
+    if (y & 1){
+      for (x=0; x<w; x++) {
+        int luma = *src++;
+	int p0 = luma - (*(srcminus+x));
+	int p1 = luma - (*(prev));
+
+	count += ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
+	++prev;
+      }
+    } else {
+      for (x=0; x<w; x++) {
+        int luma = *src++ & 0xff;
+	int p0 = luma - (*(prev+w)&0xff);
+	int p1 = luma - (*(prev)&0xff);
+
+	count += ((ABS_u8(p0) > _threshold) & (ABS_u8(p1) > _threshold));
+	++prev;
+      }
+    }
+
+    srcminus += srcpitch;
+  }
+
+  if ((100L * count) / (h * w) >= _scenethreshold){
+    scenechange = 1;
+  } else {
+    scenechange = 0;
+  }
+
+  return scenechange;
+}
+
+static int tc_detect_scenechange(unsigned char*clone, unsigned char *next, vframe_list_t *ptr){
+  const int thresh = 14;
+  const int scenethresh = 31;
+  if(ptr->v_codec == CODEC_YUV){
+    return yuv_detect_scenechange((uint8_t *)next, (uint8_t *)clone, thresh, scenethresh,
+    				ptr->v_width, ptr->v_height, ptr->v_width);
+  } else {
+    // implement RGB and YUY2
+    return 0;
+  }
+}
+/**********
+ * phosphor average will likely only make sense for YUV data.
+ * we'll do a straight average for the UV data, but for the Y
+ * data, we'll cube the pixel, average them and take the cube root
+ * of that.  This way, brightness (and hopefully motion) is easily
+ * noticed by the eye
+ **********/
+static void clone_phosphor_average(unsigned char *clone, unsigned char *next, vframe_list_t *ptr){
+  int i;
+
+  // let's not blend if there's a scenechange
+  if (tc_detect_scenechange(clone,next,ptr)){
+    return;
+  } // else 
+  for(i=0;i<(ptr->v_width*ptr->v_height);i++){
+    //ptr->video_buf[i] = (unsigned char)lrint(pow( ( pow((double)clone[i], 3.0) +
+    //					      pow((double)next[i],  3.0) ) / 2.0,
+    //					      1.0/3.0));
+    ptr->video_buf[i] = (unsigned char)lrint(pow((double) (( clone[i]*clone[i]*clone[i] +
+    					      next[i]*next[i]*next[i]) >> 1),
+					      1.0/3.0));
+  }
+  for(; i<ptr->video_size; i++){
+    ptr->video_buf[i] = (unsigned char)( ((short int)clone[i] + (short int)next[i]) >> 1);
+  }
+}
+
+static void clone_average(unsigned char *clone, unsigned char *next, vframe_list_t *ptr){
+  int i;
+
+  // let's not blend if there's a scenechange
+  if (tc_detect_scenechange(clone,next,ptr)){
+    return;
+  } // else 
+  for(i=0;i<ptr->video_size;i++){
+    ptr->video_buf[i] = (unsigned char)( ((short int)clone[i] + (short int)next[i]) >> 1);
+  }
+}
+
+static void clone_temporal_average(unsigned char *clone, unsigned char*next, vframe_list_t *ptr, int tin, int tout){
+  // basic algorithm is to weight the pixels of a frame based
+  // on how close the blended frame should be if this frame was
+  // perfectly placed  since's we'll be merging the tin and the tin+1
+  // frame into the tout'th frame, we calculate the time that
+  // tout will be played at, and compare it to tin and tin+1
+  
+  // because the main body is buffering frames, when we're called, tin and tout might
+  // not be appropriate for when clones should be called (in otherwords, the
+  // buffering allows a small amount of AV slippage) ... what this means, is
+  // that sometimes to have things match up temporally best, we should just
+  // copy in the next frame  This tends to happen when outfps < 1.5*infps
+  
+  double weight1,weight2;
+  int i;
+  static int first=1;
+
+  weight1 = 1.0 - ( (double)tout/outfps*infps - (double)tin );
+  weight2 = 1.0 - ( (double)(tin+1) - (double)(tout)/outfps*infps );
+  // weight2 is also 1.0-weight1
+  
+  if (show_results){
+    printf("[%s] temporal_clone tin=%4d tout=%4d w1=%1.5f w2=%1.5f\n",MOD_NAME,tin,tout,weight1,weight2);
+  }
+
+  if (weight1 < 0.0){
+    if (show_results){
+      printf("[%s] temporal_clone: w1 is weak, copying next frame\n",MOD_NAME);
+    }
+    memcpy(ptr->video_buf,next,ptr->video_size);
+    return;
+  } // else
+  if (weight2 < 0.0){
+    // I think this case cannot happen
+    if (show_results){
+      printf("[%s] temporal_clone: w2 is weak, simple cloning of frame\n",MOD_NAME);
+    }
+    // no memcpy needed, as we're keeping the orig
+    return;
+  } // else
+  
+  // let's not blend if there's a scenechange
+  if (tc_detect_scenechange(clone,next,ptr)){
+    return;
+  } // else 
+
+  if (weight1 > 1.0 || weight2 > 1.0){
+    fprintf(stderr, "[%s] clone_temporal_average: error: weights are out of range, w1=%f w2=%f\n", MOD_NAME,weight1,weight2);
+    return;
+  } // else 
+  
+  for(i=0; i<ptr->video_size; i++){
+    ptr->video_buf[i] = (unsigned char)( (double)(clone[i])*weight1 + (double)(next[i])*weight2);
+  }
+  first=0;
+}
+
+static void clone_interpolate(char *clone, char *next, vframe_list_t *ptr){
+  int i,width,height;
+  char *dest, *s1, *s2;
+
+  if (CODEC_RGB == ptr->v_codec){
+    // in RGB, the data is packed, three bytes per pixel
+    width = 3*ptr->v_width;
+  } else if (CODEC_YUY2 == ptr->v_codec){
+    // in YUY2, the data again is packed.
+    width = 2*ptr->v_width;
+  } else if (CODEC_YUV == ptr->v_codec){
+    // we'll handle the planar colours later
+    width = ptr->v_width;
+  }
+  height = ptr->v_height;
+  dest = ptr->video_buf;
+  s1 = clone;
+  s2 = next+width;
+  for(i=0;i<height;i++){
+    memcpy(dest,s1,width);
+    dest += width;
+    // check to make sure we don't have an odd number of rows;
+    if (++i < height){
+      memcpy(dest,s2,width);
+      dest += width;
+      s1 += width<<1;
+      s2 += width<<1;
+    }
+  }
+  if (CODEC_YUV == ptr->v_codec){
+    // here we handle the planar color part of the data
+    dest = ptr->video_buf + width*height;
+    s1 = ptr->video_buf+width*height;
+    s2 = ptr->video_buf+width*height+(width>>1);
+    // we'll save some shifting and recalc width;
+    width = width >>1;
+
+    // we don't have to divide the height by 2 because we've
+    // got two colors, we'll handle them in one sweep.
+    for(i=0;i<height;i++){
+      memcpy(dest,s1,width);
+      dest+=width;
+      // check to make sure we don't have an odd number of rows;
+      if(++i < height){
+        memcpy(dest,s2,width);
+	dest += width;
+	s1 += width<<1;
+	s2 += width<<1;
+      }
+    }
+  }
+}
+
+/******
+ * Clone takes in 2 buffers, the current vframe list (for height,width,codec,etc),
+ * and the frame number in the input and the output
+ * stream and will then do anything fancy needed
+ ******/
+static void fancy_clone(char* clone, char* next, vframe_list_t *ptr, int tin, int tout){
+  if ((ptr == NULL) || (clone == NULL) || (next == NULL) || (ptr->video_buf == NULL)){
+    fprintf(stderr,"[%s] Big error; we're about to dereference NULL\n",MOD_NAME);
+    return;
+  }
+  //printf("[%s] fancy_clone clonetype: %d tin=%4d tout=%4d\n",MOD_NAME,clonetype,tin,tout);
+  switch (clonetype){
+    case 0:
+      memcpy(ptr->video_buf,clone,ptr->video_size);
+      break;
+    case 1:
+      clone_interpolate(clone,next,ptr);
+      break;
+    case 2:
+      clone_interpolate(next,clone,ptr);
+      break;
+    case 3:
+      clone_average(clone,next,ptr);
+      break;
+    case 4:
+      clone_temporal_average(clone,next,ptr,tin,tout);
+      break;
+    case 5:
+      if (ptr->v_codec != CODEC_YUV){
+        printf("[%s] Erroor, phosphor merge only implemented for YUV data\n",MOD_NAME);
+	return;
+      }
+      clone_phosphor_average(clone,next,ptr);
+      break;
+    default:
+      printf("[%s] Error, unimplemented clonetype\n",MOD_NAME);
+      break;
+  }
+  return;
+}
+
 static int memory_init(vframe_list_t * ptr){
 
   int i;
@@ -145,7 +401,7 @@ static int memory_init(vframe_list_t * ptr){
 
   if (scanrange > ptr->video_size){
     // error, we'll overwalk boundaries later on
-    fprintf(stderr, "[%s] Error, video_size doesn't look to be big enough.\n");
+    fprintf(stderr, "[%s] Error, video_size doesn't look to be big enough (scan=%d video_size=%d).\n",MOD_NAME,scanrange,ptr->video_size);
     return -1;
   }
   
@@ -180,13 +436,11 @@ static int memory_init(vframe_list_t * ptr){
 int tc_filter(vframe_list_t * ptr, char *options)
 {
     static vob_t *vob = NULL;
-    static int frameCount = 0;
+    static int framesin = 0;
     static int init = 1;
     static int cloneq = 0; // queue'd clones ;)
     static int outframes = 0;
 
-    static double outfps = 0.0;
-
     //----------------------------------
     //
     // filter init
@@ -215,6 +469,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  optstr_get (options, "infrc", "%d", &infrc);
 	  optstr_get (options, "buffer", "%d", &numSample);
 	  optstr_get (options, "subsample", "%d", &offset);
+	  optstr_get (options, "clonetype", "%d", &clonetype);
 
 	}
 
@@ -267,6 +522,8 @@ int tc_filter(vframe_list_t * ptr, char *options)
       optstr_param(options,"examine", "How many frames to buffer", "%d", buf, "2", "25");
       sprintf(buf, "%d", offset);
       optstr_param(options, "subsample", "How many pixels to subsample", "%d", buf, "1", "256");
+      sprintf(buf, "%d", clonetype);
+      optstr_param(options, "clonetype", "How to clone frames", "%d", buf, "0", "16");
       sprintf(buf, "%d", verbose);
       optstr_param(options, "verbose", "run in verbose mode", "%d", buf, "0", "1");
       return 0;
@@ -297,25 +554,28 @@ int tc_filter(vframe_list_t * ptr, char *options)
     if ((ptr->tag & runnow) && (ptr->tag & TC_VIDEO)) {
       if (mode == 0){
         if (show_results){
-          printf("[%s] mycount=%5d id=%5d calc=%06.3lf ",MOD_NAME,frameCount,ptr->id,(double)frameCount*infps/outfps);
+          printf("[%s] in=%5d out=%5d win=%05.3f wout=%05.3f ",MOD_NAME,framesin,outframes,(double)framesin/infps,outframes/outfps);
 	} 
         if (infps < outfps){
 	  // Notes; since we currently only can clone frames (and just clone
 	  // them once, we can at most double the input framerate.
-	    if (!(ptr->attributes & TC_FRAME_WAS_CLONED)) frameCount++;
-	  if ((double)frameCount/infps > (double)++outframes/outfps){
+	  if (ptr->attributes & TC_FRAME_WAS_CLONED){
+	    // we can't clone it again, so we'll record the outframe and exit
+	    ++outframes;
+	    if (show_results){
+	      printf("\n");
+	    }
+	    return 0;
+	  } // else 
+	  if ((double)framesin++/infps > (double)outframes++/outfps){
 	    if (show_results){
 	      printf("FRAME IS CLONED");
 	    }
-	    if ((ptr->attributes & TC_FRAME_IS_CLONED) || (ptr->attributes & TC_FRAME_WAS_CLONED)){
-	      printf("Ack, this frame was cloned!\n");
-	    }
-
 	    ptr->attributes |= TC_FRAME_IS_CLONED;
 	  }
 	} else {
-	  if ((double)++frameCount/infps > outframes / outfps){
-	       outframes++; 
+	  if ((double)framesin++/infps > outframes / outfps){
+	       ++outframes; 
 	  } else {
 	    if (show_results){
 	      printf("FRAME IS SKIPPED");
@@ -338,7 +598,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  }
 	}
 	if (show_results){
-          printf("[%s] frameIn=%d frameOut=%d mycount=%5d id=%5d calc=%06.3lf ",MOD_NAME,frameIn,frameOut,frameCount-numSample,ptr->id-numSample-cloneq,(double)(frameCount-numSample)*infps/outfps);
+          printf("[%s] frameIn=%d frameOut=%d in=%5d out=%5d win=%05.3f wout=%05.3f ",MOD_NAME,frameIn,frameOut,framesin-numSample,outframes+cloneq,(double)(framesin-numSample)/infps,(double)(outframes+cloneq)/outfps);
 	}
 	if (ptr->attributes & TC_FRAME_WAS_CLONED){
 	  // don't do anything.  Since it's cloned, we don't
@@ -349,22 +609,23 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  if (framesOK[(frameIn+0)%frbufsize]){
 	    fprintf(stderr, "[%s] Oppps, this frame wasn't cloned but we thought it was\n",MOD_NAME);
 	  }
-	  ++frameCount;
+	  ++outframes;
 	  --cloneq;
 	  if (show_results){
 	    printf("no slot needed for clones\n");
 	  }
+	  fancy_clone(frames[frameIn],frames[(frameIn+1)%frbufsize],ptr,framesin-numSample,outframes+cloneq+1);
 	  return 0;
 	} // else 
 	memcpy(frames[frameIn], ptr->video_buf, ptr->video_size);
 	framesOK[frameIn] = 1;
 #ifdef DEBUG
-	printf("Inserted frame %d into slot %d \n",frameCount, frameIn);
+	printf("Inserted frame %d into slot %d \n",framesin, frameIn);
 #endif // DEBUG
 
 	// Now let's look and see if we should compute a frame's
 	// score.
-	if (frameCount > 0){
+	if (framesin > 0){
 	  char *t1, *t2;
 	  int *score,t;
 	  t=(frameIn+numSample)%frbufsize;
@@ -387,10 +648,10 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	// the first frbufsize-1 frames are not processed; only buffered
 	// so that we might be able to effectively see the future frames
 	// when deciding about a frame.
-	if(frameCount < frbufsize-1){
+	if(framesin < frbufsize-1){
 	  ptr->attributes |= TC_FRAME_IS_SKIPPED;
 	  frameIn = (frameIn+1) % frbufsize;
-	  ++frameCount;
+	  ++framesin;
 	  if (show_results){
 	    printf("\n");
 	  }
@@ -401,7 +662,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	// are ready to clone/skip a frame.  If we are, we look for the frame to skip
 	// in the buffer
 	if (infps < outfps){
-	  if ((double)(frameCount-numSample)*infps/outfps < (double)(ptr->id-numSample-cloneq)){
+	  if ((double)(framesin-numSample)/infps > (double)(cloneq+outframes++)/outfps){
 	    // we have to find a frame to clone
 	    int diff=-1, mod=-1;
 #ifdef DEBUG
@@ -421,7 +682,6 @@ int tc_filter(vframe_list_t * ptr, char *options)
 		}
 	      }
 	    }
-	    fflush(stdout);
 	    if (mod == -1){
 	      fprintf(stderr,"[%s] Error calculating frame to clone\n",MOD_NAME);
 	      return -1;
@@ -446,7 +706,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  frameOut = (frameOut+1) % frbufsize;
 	} else {
 	  // check to skip frames
-	  if ((double)(frameCount-numSample)*infps/outfps > (double)(ptr->id-numSample)){
+	  if ((double)(framesin-numSample)/infps < (double)(outframes)/outfps){
 	    int diff=INT_MAX, mod=-1;
 
 	    // since we're skipping, we look for the frame with the lowest
@@ -467,8 +727,9 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	      fprintf(stderr,"[%s] Error calculating frame to skip\n",MOD_NAME);
 	      return -1;
 	    }
-	    --frameCount;
 	    framesOK[mod] = 0;
+	  } else {
+	    ++outframes;
 	  }
 	  if (framesOK[frameOut]){
 	    memcpy(ptr->video_buf,frames[frameOut],ptr->video_size);
@@ -484,7 +745,7 @@ int tc_filter(vframe_list_t * ptr, char *options)
 	  frameOut = (frameOut+1) % frbufsize;
 	}
 	frameIn = (frameIn+1) % frbufsize;
-	++frameCount;
+	++framesin;
 	return 0;
       }
       fprintf(stderr, "[%s] Oppps, currently only 2 modes of operation\n",MOD_NAME);
