@@ -35,7 +35,7 @@
 
 
 #define MOD_NAME    "filter_pv.so"
-#define MOD_VERSION "v0.2.2 (2003-02-27)"
+#define MOD_VERSION "v0.2.3 (2004-06-01)"
 #define MOD_CAP     "xv only preview plugin"
 #define MOD_AUTHOR  "Thomas Oestreich, Tilmann Bitterberg"
 
@@ -128,19 +128,19 @@ void preview_toggle_skip()
 char * preview_alloc_align_buffer(size_t size)
 {
 #ifdef HAVE_GETPAGESIZE
-   int buffer_align=getpagesize();
+   long buffer_align=getpagesize();
 #else
-   int buffer_align=0;
+   long buffer_align=0;
 #endif
    char *buf = malloc(size + buffer_align);
 
-   int adjust;
+   long adjust;
 
    if (buf == NULL) {
        fprintf(stderr, "(%s) out of memory", __FILE__);
    }
    
-   adjust = buffer_align - ((int) buf) % buffer_align;
+   adjust = buffer_align - ((long) buf) % buffer_align;
 
    if (adjust == buffer_align)
       adjust = 0;
@@ -171,7 +171,7 @@ int tc_filter(vframe_list_t *ptr, char *options)
   // (6) filter is last time with TC_FILTER_CLOSE flag set
 
   if(ptr->tag & TC_FILTER_GET_CONFIG) {
-      optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VYO", "1");
+      optstr_filter_desc (options, MOD_NAME, MOD_CAP, MOD_VERSION, MOD_AUTHOR, "VY4O", "1");
       optstr_param (options, "cache", "Number of raw frames to cache for seeking",  "%d", "15", "15", "255");
       optstr_param (options, "skip", "display only every Nth frame",  "%d", "0", "0", "255");
   }
@@ -227,17 +227,25 @@ int tc_filter(vframe_list_t *ptr, char *options)
     
     switch(vob->im_v_codec) {
       
+    case CODEC_YUV422:
+      
+      if(xv_display_init(xv_player->display, 0, NULL, 
+			 w, h, buffer, buffer, 1)<0) return(-1);
+			 size = w*h*2;
+
+      break;
+    
     case CODEC_YUV:
       
       if(xv_display_init(xv_player->display, 0, NULL, 
-			 w, h, buffer, buffer)<0) return(-1);
+			 w, h, buffer, buffer, 0)<0) return(-1);
 
       break;
     
     case CODEC_RAW_YUV:
     
       if(xv_display_init(xv_player->display, 0, NULL, 
-			  w, h, buffer, buffer)<0) return(-1);
+			  w, h, buffer, buffer, 0)<0) return(-1);
       use_secondary_buffer=1;
       break;
       
