@@ -80,7 +80,7 @@ MOD_open
 
 	if(vob->fixme_a_codec==CODEC_AC3) {
 	
-	    if((snprintf(import_cmd_buf, MAX_BUF, "tcextract -a %d -i \"%s\" -x ac3 -d %d | tcdecode -x ac3 -d %d -s %f,%f,%f", vob->a_track, vob->audio_in_file, vob->verbose, vob->verbose, vob->ac3_gain[0], vob->ac3_gain[1], vob->ac3_gain[2])<0)) {
+	    if((snprintf(import_cmd_buf, MAX_BUF, "tcextract -a %d -i \"%s\" -x ac3 -d %d | tcdecode -x ac3 -d %d -s %f,%f,%f -A %d", vob->a_track, vob->audio_in_file, vob->verbose, vob->verbose, vob->ac3_gain[0], vob->ac3_gain[1], vob->ac3_gain[2], vob->a52_mode)<0)) {
 		perror("command buffer overflow");
 		return(TC_IMPORT_ERROR);
 	    }
@@ -91,7 +91,7 @@ MOD_open
 
 	if(vob->fixme_a_codec==CODEC_A52) {
 	    
-	    if((snprintf(import_cmd_buf, MAX_BUF, "tcextract -a %d -i \"%s\" -x a52 -d %d | tcdecode -x a52 -d %d", vob->a_track, vob->audio_in_file, vob->verbose, vob->verbose)<0)) {
+	    if((snprintf(import_cmd_buf, MAX_BUF, "tcextract -a %d -i \"%s\" -x a52 -d %d | tcdecode -x a52 -d %d -A %d", vob->a_track, vob->audio_in_file, vob->verbose, vob->verbose, vob->a52_mode)<0)) {
 		perror("command buffer overflow");
 		return(TC_IMPORT_ERROR);
 	    }
