@@ -12,7 +12,7 @@
 #include "transcode.h"
 
 #define MOD_NAME    "import_vnc.so"
-#define MOD_VERSION "v0.0.1 (2003-09-01)"
+#define MOD_VERSION "v0.0.2 (2003-11-29)"
 #define MOD_CODEC   "(video) VNC"
 
 #define MOD_PRE vnc
@@ -71,7 +71,8 @@ MOD_open
 	    case 0:
 		{
 		    int n=0;
-		    char *a[6];
+		    char *a[16];
+		    char *c = vob->im_v_string;
 
 		    setenv("VNCREC_MOVIE_FRAMERATE", fps, 1);
 		    setenv("VNCREC_MOVIE_CMD", cmdbuf, 1);
@@ -82,16 +83,43 @@ MOD_open
 		    a[n++] = "vncrec";
 		    a[n++] = "-movie";
 		    a[n++] = vob->video_in_file;
+		    if ( vob->im_v_string) {
+			char *d = c;
+			while (1) {
+			    if (c && *c) { 
+				d = strchr (c, ' ');
+				if (d && *d) { *d = '\0';
+				    while (*c == ' ') c++;
+				    a[n++] = c;
+				    printf("XX |%s|\n", c);
+				    c = strchr(c, ' ');
+				} else {
+				    printf("XXXX |%s|\n", c);
+				    a[n++] = c;
+				    break;
+				}
+			    } else  {
+				d++;
+				while (*d == ' ') d++;
+				if (strchr(d, ' ')) *strchr(d, ' ') = '\0';
+				a[n++] = d;
+				printf("XXX |%s|\n", d);
+				break;
+			    }
+			}
+		    }
 		    a[n++] = NULL;
 		    if (execvp (a[0], &a[0])<0) {
-			perror ("execvp vncrec. Is vncrec in your $PATH?");
+			perror ("execvp vncrec failed. Is vncrec in your $PATH?");
+			return (TC_IMPORT_ERROR);
 		    }
 		}
 		break;
 	    default:
 		break;
 	}
-	fprintf(stderr, "Main here\n");
+	//fprintf(stderr, "Main here\n");
+
 
 	return (TC_IMPORT_OK);
     }
@@ -113,11 +141,12 @@ MOD_decode
 	fd_set rfds;
 	struct timeval tv;
 	int n;
+	extern int tc_dvd_access_delay;
 
 	while (1) {
 
 	    // timeout to catch when vncrec died
-	    tv.tv_sec = 5;
+	    tv.tv_sec = tc_dvd_access_delay;
 	    tv.tv_usec = 0;
 
 	    fd = open(fifo, O_RDONLY | O_NONBLOCK);
