@@ -83,16 +83,23 @@ void tcprobe_thread(info_t *ipipe)
     case TC_MAGIC_GIF:
     case TC_MAGIC_PPM:
     case TC_MAGIC_PGM:
+    case TC_MAGIC_SGI:
       probe_im(ipipe);
 
       break;
 
+    case TC_MAGIC_MXF:
+      probe_mxf(ipipe);
+
+      break;
+
     case TC_MAGIC_V4L_VIDEO:
 	ipipe->probe_info->magic = TC_MAGIC_V4L_VIDEO;
 	ipipe->probe_info->width  = 352;
 	ipipe->probe_info->height = 288;
 
 	break;
+
     case TC_MAGIC_V4L_AUDIO:
 	ipipe->probe_info->magic = TC_MAGIC_V4L_AUDIO;
 
