@@ -126,7 +126,7 @@ int main(int argc, char *argv[])
 {
 
 	vob_t s_vob,*p_vob;
-	char s_cmd,*p_in_v_file="/dev/stdin",*p_in_a_file=NULL,*p_audio_tmp,*p_video_tmp;
+	char s_cmd,*p_in_v_file="/dev/stdin",*p_in_a_file=NULL,*p_audio_tmp=NULL,*p_video_tmp=NULL;
 	pid_t s_pid;
 	int s_bin_dump=0,s_type_check=VIDEO_MODE|AUDIO_MODE,s_shmem=0;
 	int s_shm,s_rc;
@@ -203,7 +203,7 @@ int main(int argc, char *argv[])
 			fprintf(stderr,"(%s) Cannot create shared memory segment\n",EXE);
 			exit(1);
 		}
-		if ((p_vob=(vob_t *)shmat(s_shm,NULL,0)) == -1)
+		if ((p_vob=(vob_t *)shmat(s_shm,NULL,0)) == (vob_t *)-1)
 		{
 			shmctl( s_shm, IPC_RMID, p_vob );
 			(int) shmdt(p_vob);
@@ -221,7 +221,7 @@ int main(int argc, char *argv[])
 			fprintf(stderr,"(%s) Cannot create shared memory segment: use -S option to create it\n",EXE);
 			exit(1);
 		}
-		if ((p_vob=(vob_t *)shmat(s_shm,NULL,0)) == -1)
+		if ((p_vob=(vob_t *)shmat(s_shm,NULL,0)) == (vob_t *)-1)
 		{
 			shmctl( s_shm, IPC_RMID, p_vob );
 			(int) shmdt(p_vob);
@@ -270,7 +270,7 @@ int main(int argc, char *argv[])
 				fprintf(stderr,"(%s) Error writing data to stdout\n",EXE);
 				exit(1);
 			}
-			if(p_write(STDOUT_FILENO, &s_rc, sizeof(int)) != sizeof(int))
+			if(p_write(STDOUT_FILENO, (char *)&s_rc, sizeof(int)) != sizeof(int))
 			{
 				fprintf(stderr,"(%s) Error writing data to stdout\n",EXE);
 				exit(1);
