@@ -32,8 +32,12 @@
 #include <ctype.h>
 #include <strings.h>
 #include <string.h>
+#include <pvm_parser.h>
 
 #define MAX_BUF	1024
 int f_multiplexer(char *p_codec,char *p_merge_cmd,char *p_video_filename,char *p_audio_filename,char *p_dest_file,int s_verbose);
 char *f_external_suffix(char *p_codec,char *p_param);
+int f_supported_export_module(char *p_codec);
+char *f_supported_system(pvm_config_codec *p_v_codec,pvm_config_codec *p_a_codec);
+void f_help_codec (char *p_module);
 #endif
