@@ -119,14 +119,14 @@ void import_threads_cancel()
   }
 
   //wait for threads to terminate
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
   pthread_cond_signal(&vframe_list_full_cv);
 #endif
   cc1=pthread_join(vthread, &status);
   
   if(verbose & TC_DEBUG) fprintf(stderr, "(%s) video thread exit (ret_code=%d) (status_code=%d)\n", __FILE__, cc1, (int) status);
   
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
   pthread_cond_signal(&aframe_list_full_cv);
 #endif
   cc2=pthread_join(athread, &status);
@@ -471,7 +471,7 @@ void vimport_thread(vob_t *vob)
     
     while(vframe_fill_level(TC_BUFFER_FULL)) {
 	pthread_cond_wait(&vframe_list_full_cv, &vframe_list_lock);
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
 	pthread_testcancel();
 #endif
 	
@@ -659,7 +659,7 @@ void aimport_thread(vob_t *vob)
     
     while(aframe_fill_level(TC_BUFFER_FULL)) {
       pthread_cond_wait(&aframe_list_full_cv, &aframe_list_lock);
-#ifdef __APPLE__ // MacOSX: Broken pthreads
+#ifdef BROKEN_PTHREADS // Used to be MacOSX specific; kernel 2.6 as well?
       pthread_testcancel();
 #endif
 
