@@ -21,7 +21,7 @@
  *
  */
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 
 #ifdef HAVE_DLFCN_H
