@@ -40,11 +40,13 @@ static char *std_module[] = {"null",
 			     "ogg",
 			     "mov",
 			     "v4l",
+			     "v4l2",
 			     "xml",
 			     "lav",
 			     "lzo",
 			     "ts",
 			     "vnc",
+			     "fraps",
 			     "mplayer"
 };
 
@@ -61,11 +63,13 @@ enum _std_module {_null_,
 		  _ogg_,
 		  _mov_,
 		  _v4l_,
+		  _v4l2_,
 		  _xml_,
 		  _lav_,
 		  _lzo_,
 		  _ts_,
 		  _vnc_,
+		  _fraps_,
 		  _theora_
 };
 
@@ -405,6 +409,21 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
 
     break;
 
+  case TC_MAGIC_V4L2_VIDEO:
+    vob->vmod_probed=std_module[_v4l2_];
+    preset |= TC_VIDEO;
+
+    if( !(*flag & TC_PROBE_NO_FRAMESIZE) && vob->im_v_codec == CODEC_RGB) {
+	vob->im_v_width  = PAL_W/2;
+	vob->im_v_height = PAL_H/2;
+    }
+    if( !(*flag & TC_PROBE_NO_FRAMESIZE) && vob->im_v_codec == CODEC_YUV) {
+	vob->im_v_width  = 352;
+	vob->im_v_height = 288;
+    }
+
+    break;
+
   case TC_MAGIC_SOCKET:
     vob->vmod_probed=std_module[_net_];
     break;
@@ -526,6 +545,11 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
       preset |= TC_AUDIO;
       break;
       
+  case TC_MAGIC_V4L2_AUDIO:
+      vob->amod_probed=std_module[_v4l2_];
+      preset |= TC_AUDIO;
+      break;
+      
   case TC_MAGIC_WAV:
     // vob->amod_probed=std_module[_yuv4mpeg_];
     vob->amod_probed=std_module[_raw_];
@@ -625,10 +649,13 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
   case TC_CODEC_MP42:
   case TC_CODEC_MP43:
   case TC_CODEC_RV10:
+  case TC_CODEC_ASV1:
+  case TC_CODEC_ASV2:
+  case TC_CODEC_FFV1:
     vob->im_v_codec=CODEC_YUV;
 
     //overwrite pass-through selection!
-    vob->vmod_probed=std_module[_ffmpeg_];
+    if(!(preset & TC_VIDEO)) vob->vmod_probed=std_module[_ffmpeg_];
     preset |= TC_VIDEO;
     
     if(preset & TC_AUDIO) break;
@@ -674,7 +701,7 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
     // if input is ogg, do not probe video
     if (probe_further_for_codec) {
 	//overwrite pass-through selection!
-	vob->vmod_probed=std_module[_ffmpeg_];
+	if (!(preset & TC_VIDEO)) vob->vmod_probed=std_module[_ffmpeg_];
 	preset |= TC_VIDEO;
 	if(preset & TC_AUDIO) break;
     }
@@ -685,6 +712,20 @@ void probe_source(int *flag, vob_t *vob, int range, char *vid_file, char *aud_fi
     
     break;
     
+  case TC_CODEC_FRAPS:
+    vob->im_v_codec=CODEC_YUV;
+
+    //overwrite pass-through selection!
+    vob->vmod_probed=std_module[_fraps_];
+    preset |= TC_VIDEO;
+    
+    if(preset & TC_AUDIO) break;
+    
+    //audio
+    vob->amod_probed=get_audio_module(vob->fixme_a_codec, vob->has_audio);
+    preset |= TC_AUDIO;  
+    break;
+
   case TC_CODEC_YV12:
     vob->im_v_codec=CODEC_YUV;
 
