@@ -25,7 +25,7 @@
 #define _TRANSCODE_H
 
 #ifdef HAVE_CONFIG_H
-#include "../config.h"
+#include "config.h"
 #endif
 
 #include <stdio.h>
@@ -56,6 +56,27 @@ typedef unsigned int uint32_t;
 #include "tc_defaults.h"
 #include "tc_functions.h"
 
+/* ----------------------------
+ * 
+ * mpeg profiles for setting
+ * sensible defaults
+ *
+ * ----------------------------*/
+
+typedef enum {
+  PROF_NONE = 0,
+  VCD,
+  VCD_PAL,
+  VCD_NTSC,
+  SVCD,
+  SVCD_PAL,
+  SVCD_NTSC,
+  DVD,
+  DVD_PAL,
+  DVD_NTSC,
+} mpeg_profile_t;
+
+
 /* ----------------------------
  *
  * global information structure
@@ -191,7 +212,13 @@ typedef struct _vob_t {
   int v_bpp;                // defaults to BPP
   
   int im_asr;               // import aspect ratio code  
+  int im_par;               // import pixel aspect (code)
+  int im_par_width;         // import pixel aspect width
+  int im_par_height;        // import pixel aspect height
   int ex_asr;               // export aspect ratio code  
+  int ex_par;               // export pixel aspect (code)
+  int ex_par_width;         // export pixel aspect width
+  int ex_par_height;        // export pixel aspect height
   int attributes;           // more video frame attributes 
 
   int im_v_codec;           // true frame buffer video codec
@@ -337,6 +364,8 @@ typedef struct _vob_t {
 
   int video_frames_delay; // delay audio by N frames, (video is late)
   float m2v_requant;    // Requantize Factor for mpeg2 video streams
+
+  mpeg_profile_t mpeg_profile;
   
 } vob_t;
 
@@ -380,6 +409,9 @@ typedef struct probe_info_s {
   int asr;                //aspect ratio code
   int frc;                //frame cate code
 
+  int par_width;          // pixel aspect (== sample aspect ratio)
+  int par_height;
+
   int attributes;         //video attributes
   
   int num_tracks;         //number of audio tracks
@@ -413,16 +445,8 @@ typedef struct _info_t {
   
   long magic;     // specifies file magic for extract thread
   int track;      // extract this track
-  
-  int width;      // logical stream parameter
-  int height;     // logical stream parameter
-
-  int padrate;    // zero padding rate
-  
   long stype;     // specifies stream type for extract thread
-  long codec;     // specifies codec for decoder thread
-  
-  long format;    // specifies raw stream format for decoder output
+  long codec;     // specifies codec for extract thread
   int verbose;    // verbosity
 
   int dvd_title;
@@ -431,8 +455,6 @@ typedef struct _info_t {
 
   int vob_offset;
 
-  int a52_mode;
- 
   int ps_unit;
   int ps_seq1;
   int ps_seq2;
@@ -444,7 +466,7 @@ typedef struct _info_t {
   int demux;      // demux or debug
   int select;     // selected packet payload type
   int subid;      // selected packet substream id
-  int keep_seq;   // do not drop firsat sequence (cluster mode)
+  int keep_seq;   // do not drop first sequence (cluster mode)
 
   double fps;
 
@@ -461,14 +483,31 @@ typedef struct _info_t {
   int quality;
   int error;
 
-  double ac3_gain[3];
   long frame_limit[3];
-
-  int dv_yuy2_mode;
   int hard_fps_flag;    // if this is set, disable smooth drop in demuxer
 
 } info_t;
 
+typedef struct {
+  int fd_in;      // input stream file descriptor
+  int fd_out;     // output stream file descriptor
+  double ac3_gain[3];
+  long frame_limit[3];
+  int dv_yuy2_mode;
+  int padrate;    // zero padding rate
+  long magic;     // specifies file magic
+  long stype;     // specifies stream type
+  long codec;     // specifies codec for
+  int verbose;    // verbosity
+  int quality;
+  char *name;     // source name as supplied with -i option
+  int width;      // logical stream parameter
+  int height;     // logical stream parameter
+  int a52_mode;
+  long format;    // specifies raw stream format for output
+  int select;     // selected packet payload type
+} decode_t;
+
 typedef struct subtitle_header_s {
 
   unsigned int header_length;   
@@ -550,7 +589,7 @@ extern int tc_y_preview;
 extern int tc_progress_meter;
 extern pthread_t tc_pthread_main;
 extern int tc_accel;
-extern int tc_avi_limit;
+extern unsigned int tc_avi_limit;
 extern int tc_frame_width_max;
 extern int tc_frame_height_max;
 extern pid_t tc_probe_pid;
