@@ -31,7 +31,7 @@
 #include <string.h>
 
 #include "avilib.h"
-#include "../config.h"
+#include "config.h"
 #include "transcode.h"
 
 #include "aud_scan.h"
@@ -40,7 +40,7 @@
 
 void version()
 {
-  printf("%s (%s v%s) (C) 2001-2003 Tilmann Bitterberg\n", EXE, PACKAGE, VERSION);
+  printf("%s (%s v%s) (C) 2003-2004 Tilmann Bitterberg\n", EXE, PACKAGE, VERSION);
 }
 
 
@@ -102,18 +102,8 @@ int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key
 	 //fprintf (stderr, "Found an index chunk at %lld len %lld\n", *pos, *len);
          if(lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
 	 return 10;
-         continue;
       }
 
-      /* if we got a list tag, ignore it */
-
-      if(strncasecmp(data,"LIST",4) == 0)
-      {
-         lseek(AVI->fdes,4,SEEK_CUR);
-         continue;
-      }
-
-
       if(strncasecmp(data,AVI->video_tag,3) == 0)
       {
          *len = str2ulong(data+4);
@@ -211,12 +201,51 @@ int AVI_read_data_fast(avi_t *AVI, char *buf, off_t *pos, off_t *len, off_t *key
          if(lseek(AVI->fdes,n-rlen,SEEK_CUR)==(off_t)-1)  return 0;
          return 9;
          break;
+      } else {
+	  lseek(AVI->fdes,-4,SEEK_CUR);
       }
-      else
-         if(lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
+      // else if(lseek(AVI->fdes,n,SEEK_CUR)==(off_t)-1)  return 0;
    }
 }
 
+int is_key(unsigned char *data, long size, char *codec) 
+{
+    if (strncasecmp(codec, "div3", 4) == 0) {
+
+	int32_t c=( (data[0]<<24) | (data[1]<<16) | (data[2]<<8) | (data[3]&0xff) );
+	if(c&0x40000000) return(0);
+	else return 1;
+
+    } else if (strncasecmp(codec, "xvid", 4) == 0 || strncasecmp(codec, "divx", 4) == 0
+	    || strncasecmp(codec, "dx50", 4) == 0 || strncasecmp(codec, "div4", 4) == 0
+	    || strncasecmp(codec, "mpg4", 4) == 0) {
+        int result = 0;
+        int i;
+
+        for(i = 0; i < size - 5; i++)
+        {
+                if( data[i]     == 0x00 && 
+                        data[i + 1] == 0x00 &&
+                        data[i + 2] == 0x01 &&
+                        data[i + 3] == 0xb6)
+                {
+                        if((data[i + 4] & 0xc0) == 0x0) 
+                                return 1;
+                        else
+                                return 0;
+                }
+        }
+        
+        return result;
+
+    }
+
+    // mjpeg, uncompressed, etc
+    return 1;
+
+}
+
+
 int main(int argc, char *argv[])
 {
 
@@ -250,6 +279,7 @@ int main(int argc, char *argv[])
   int vid_chunks=0, aud_chunks[AVI_MAX_TRACKS];
   off_t pos, len, key, index_pos=0, index_len=0,size=0;
   struct stat st;
+  char *codec;
   int idx_type=0;
   off_t ioff;
 
@@ -346,6 +376,7 @@ int main(int argc, char *argv[])
     aud_tracks = frames = 0;
     frames = AVI_video_frames(avifile1);
     fps    = AVI_frame_rate  (avifile1);
+    codec  = AVI_video_compressor(avifile1);
 
     aud_tracks = AVI_audio_tracks(avifile1);
     //printf("frames (%ld), aud_tracks (%d)\n", frames, aud_tracks);
@@ -380,8 +411,7 @@ int main(int argc, char *argv[])
 	case 1: sprintf(tag, "00db");
 		print_ms = vid_ms = (avifile1->video_pos)*1000.0/fps;
 		chunk = avifile1->video_pos;
-		if (avifile1->video_index) 
-		  key = (avifile1->video_index[chunk-1].key)?1:0;
+		key = is_key(data, LEN, codec);
 		break;
 	case 2: case 3:
 	case 4: case 5:
